package no.hig.okolloen.graphics;

import java.awt.*;
import no.hig.okolloen.graphics.digit.*;

/**
 * DigitStrip is a class used for showing more than one digit.
 * This class uses the DigitCellPane class to show the individual digits.
 * You can set the number of digits shown and what style to use. 
 * See the ImageColl class for the digits and other signs available.
 * <p>
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class DigitStrip extends Panel {
    private DigitCellPane[] cells;
    private int digits;

    /**
     *	Default constructor for the DigitStrip class.
     *  @param images Object of the ImageColl class, holding the images for the style that will be used in this DigitStrip.
     *  @param digits The maximum number of digits that will be shown in this DigitStrip.
     */
    public DigitStrip (ImageColl images, int digits) {
        super ();
        this.digits = digits;
        cells = new DigitCellPane [digits];
        for (int i=0; i<digits; i++)
            cells[i] = new DigitCellPane (images);
        setLayout (new FlowLayout());
        Panel p = new Panel ();
        p.setLayout (new GridLayout (1, digits));
        for (int i=0; i<digits; i++)
            p.add (cells[i]);
        add (p);
    }

    /**
     *	Sets the value displayed in this digitStrip.
     *  @param value, the new value to be displayed.
     */
    public void setValue (String value) {
        if (value.length() > digits) {
            for (int i=0; i<digits; i++)
                cells[i].setState ("0");
        } else {
            for (int i=0; i<(digits-value.length()); i++)
                cells[i].setState ("0");
            for (int i=digits-value.length(); i<digits; i++)
                cells[i].setState (value.substring (i-(digits-value.length()), (i-(digits-value.length()))+1));
        }
    }
}