package no.hig.okolloen.graphics;

import java.awt.*;
import java.awt.event.*;

/**
 * Knob is the basis if other dialknob classes and provides the display
 * of a basic knob and interaction with the mouse.
 * You can set various options for the Knob component like :
 * <ul>
 * <li>The max and min angle used as the active area
 * <li>The max and min values returned by this component
 * <li>The color of the top of the knob
 * </ul>
 * <p>
 * The knob component is freely scalable in both directions.
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class LabeledKnob extends MarkedKnob {
    String[] labels = null;
    int labeledKnobxOffset = 8;
    int labeledKnobyOffset = 8;

    public LabeledKnob () {
        super ();
        knobxoffset += 6;
        knobyoffset += 6;
        markedKnobxOffset += 6;
        markedKnobyOffset += 6;
    }

    /**
     *  Updates this component.
     *  @param g the graphics context.
     *  @see java.awt.Component#update
     */
    public void update(Graphics g) {
        paint(g);
    }

    /**
     *  Sets the labels for this knob
     *  @param labels String[] with the new labels
     */
    public void setLabels (String[] labels) {
        this.labels = labels;
        repaint ();
    }

    /**
     *  Gets the labels for this knob
     *  @return String[] with the labels
     */
    public String[] getLabels () {
        return labels;
    }

    /**
     *	Paints this component.
     *	@param g the graphics context.
     *	@see java.awt.Component#paint
     */	
    public void paint(Graphics g) {
        super.paint (g);
        FontMetrics fm = g.getFontMetrics();
        int labelWidth = fm.stringWidth ("H");
        int labelHeight = fm.getHeight();
        if (labels==null)
            return;
        int height = getSize().height;
        int width = getSize().width;

        Rectangle clip = g.getClipBounds();
       
        bg.setColor (Color.red);
        double radius = (width-labeledKnobxOffset*2)/2-2;
        double offset = (double)width/(double)2;
        double piQuarterSin = java.lang.Math.sin(java.lang.Math.PI/4);
        if (labels.length==2) {
            // lower right
            bg.drawString (labels[1], (int)(offset+radius*piQuarterSin), (int)(offset+radius*piQuarterSin)+labelHeight/3);
            // lower left
            bg.drawString (labels[0], (int)(offset-radius*piQuarterSin)-fm.stringWidth(labels[0]), (int)(offset+radius*piQuarterSin)+labelHeight/3);
        } else if (labels.length==3) {
            // lower right
            bg.drawString (labels[2], (int)(offset+radius*piQuarterSin), (int)(offset+radius*piQuarterSin)+labelHeight/3);
            // top
            bg.drawString (labels[1], (int)(offset)-fm.stringWidth(labels[1])/2, (int)(offset-radius));
            // lower left
            bg.drawString (labels[0], (int)(offset-radius*piQuarterSin)-fm.stringWidth(labels[0]), (int)(offset+radius*piQuarterSin)+labelHeight/3);
        } else if (labels.length==7) {
            // lower right
            bg.drawString (labels[6], (int)(offset+radius*piQuarterSin), (int)(offset+radius*piQuarterSin)+labelHeight/3);
            // right
            bg.drawString (labels[5], (int)(offset+radius), (int)(offset)+labelHeight/3);
            // upper right
            bg.drawString (labels[4], (int)(offset+radius*piQuarterSin), (int)(offset-radius*piQuarterSin)+labelHeight/3);
            // top
            bg.drawString (labels[3], (int)(offset)-fm.stringWidth(labels[1])/2, (int)(offset-radius));
            // upper left
            bg.drawString (labels[2], (int)(offset-radius*piQuarterSin)-fm.stringWidth(labels[2]), (int)(offset-radius*piQuarterSin)+labelHeight/3);
            // left
            bg.drawString (labels[1], (int)(offset-radius)-fm.stringWidth(labels[1]), (int)(offset)+labelHeight/3);
            // lower left
            bg.drawString (labels[0], (int)(offset-radius*piQuarterSin)-fm.stringWidth(labels[0]), (int)(offset+radius*piQuarterSin)+labelHeight/3);
        }
        if(clip != null)
            g.setClip(clip);

        g.drawImage(buffer, 0, 0, this);
    }
}