package no.hig.okolloen.graphics.chart;

import java.awt.*;

/**
 * The BarChart class is used to draw (take a guess) bar Charts.
 * Data is provided by an instance of the ScaledChartDataSet.
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class BarChart extends Chart {
    int position;
    int increment;
    ScaledChartDataSet dataSet;
    boolean showTitles = false;

    /**
     *	Constructor for the Chart class.
     *  @param dataSet the instance of the ScaledChartDataSet that acts as a data provider.
     */
    public BarChart (ScaledChartDataSet dataSet) {
        super ();
        this.dataSet = dataSet;
        labels = dataSet.getScaleLabels ();
    }

    /**
     *	Constructor for the Chart class.
     *  @param dataSet the instance of the ScaledChartDataSet that acts as a data provider.
     *  @param showTitles boolean value that determines if the titles given trough the dataset is to be shown above each bar.
     */
    public BarChart (ScaledChartDataSet dataSet, boolean showTitles) {
        super ();
        this.dataSet = dataSet;
        labels = dataSet.getScaleLabels ();
        this.showTitles = showTitles;
    }

    /**
     *	Updates this component.
     *  @param g the Graphics context.
     *	@see java.awt.Component#update
     */
    public void update(Graphics g) {
        paint(g);
    }

    /**
     *	Paints this component.
     *	@param g the Graphics context.
     *	@see java.awt.Component#paint
     */	
    public void paint (Graphics g) {
        super.paint (g);
        int height = getSize().height;
        int width = getSize().width;
     
        increment = (right-left)/dataSet.size();
        position = left;
        Color temp = bg.getColor ();
        for (int i=0; i<dataSet.size(); i++) {
            ChartItem item = (ChartItem)dataSet.getElementAt(i);
            int adjustedValue = (int)(bottom-(bottom-top)*dataSet.getScaledElementAt(i));
            bg.setColor (item.getColor());
            bg.fillRect (position+1, adjustedValue, increment-1, bottom-adjustedValue);
            position+=increment;
        }
        bg.setColor (fgColor);
        if (showTitles) {
            position = left;
            for (int i=0; i<dataSet.size(); i++) {
                ChartItem item = (ChartItem)dataSet.getElementAt(i);
                int adjustedValue = (int)(bottom-(bottom-top)*dataSet.getScaledElementAt(i));
                if (item.getTitle()!=null)
                    bg.drawString (item.getTitle(), position+(increment-fm.stringWidth(item.getTitle()))/2, adjustedValue-2);
                position+=increment;
            }
        }
        bg.setColor (temp);
        g.drawImage(buffer, 0, 0, this);
        g.dispose ();
    }

    /**
     *	Returns the preferred size of this component.
     *	@return A Dimension object representing the preferred size of this component.
     *	@see java.awt.Component#getPreferredSize
     */
    public Dimension getPreferredSize() {
        return new Dimension(300, 200);
    }
}