package no.hig.okolloen.graphics.chart;

import java.util.Vector;
import java.awt.Color;

/**
 * The ChartDataSet class is used to hold data values used by LineChart and BarChart.
 * It is more or less just a vector of ChartItems.
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class ChartDataSet {
    Vector dataSet = new Vector ();
    int maxElements = 10;

    /**
     *	Constructor for the ChartDataSet class.
     *  @param maxElements the maximum number of elements held by this ChartDataSet.
     */
    public ChartDataSet (int maxElements) {
        this.maxElements = maxElements;
    }

    /**
     *	Adds an element to the ChartDataSet.
     *  If this results in more than the maximum number of items being held in the 
     *  dataset the first element is thrown away.
     *  @param item the ChartItem to add.
     */
    public void addElement (ChartItem item) {
        if (dataSet.size()>maxElements)
            dataSet.removeElementAt (0);
        dataSet.addElement (item);
    }

    /**
     *	Adds an element to the ChartDataSet.
     *  If this results in more than the maximum number of items being held in the 
     *  dataset the first element is thrown away.
     *  @param value the value of this datapoint.
     */
    public void addElement (double value) {
        if (dataSet.size()>maxElements)
            dataSet.removeElementAt (0);
        dataSet.addElement (new ChartItem (value));
    }

    /**
     *	Adds an element to the ChartDataSet.
     *  If this results in more than the maximum number of items being held in the 
     *  dataset the first element is thrown away.
     *  @param value the value of this datapoint.
     *  @param color the color that will be used when representing this datapoint
     */
    public void addElement (double value, Color color) {
        if (dataSet.size()>maxElements)
            dataSet.removeElementAt (0);
        dataSet.addElement (new ChartItem (value, color));
    }

    /**
     *	Adds an element to the ChartDataSet.
     *  If this results in more than the maximum number of items being held in the 
     *  dataset the first element is thrown away.
     *  @param value the value of this datapoint.
     *  @param color the color that will be used when representing this datapoint
     *  @param title the title to give this datapoint
     */
    public void addElement (double value, Color color, String title) {
        if (dataSet.size()>maxElements)
            dataSet.removeElementAt (0);
        dataSet.addElement (new ChartItem (title, value, color));
    }

    /**
     *	Sets element at given index in the ChartDataSet to given value.
     *  @param element the index in the ChartDataSet where this item is to be placed.
     *  @param item the item to put into this position.
     */
    public void setElementAt (int element, ChartItem item) {
        dataSet.setElementAt (item, element);
    }

    /**
     *	Sets element at given index in the ChartDataSet to given value.
     *  @param value the value of this datapoint.
     */
    public void setElementAt (int element, double value) {
        dataSet.setElementAt (new ChartItem (value), element);
    }

    /**
     *	Sets element at given index in the ChartDataSet to given value and color.
     *  @param value the value of this datapoint.
     *  @param color the color of used for the datapoint.
     */
    public void setElementAt (int element, double value, Color color) {
        dataSet.setElementAt (new ChartItem (value, color), element);
    }

    /**
     *	Sets element at given index in the ChartDataSet to given value, color and with given title.
     *  @param value the value of this datapoint.
     *  @param color the color of used for the datapoint.
     *  @param title the title to use for this datapoint.
     */
    public void setElementAt (int element, double value, Color color, String title) {
        dataSet.setElementAt (new ChartItem (title, value, color), element);
    }

    /**
     *  Removes the element at the given index. 
     *  all elements behind this index will be shifted down.
     *  @param element the index of the element to be removed.
     */
    public void removeElementAt (int element) {
        dataSet.removeElementAt (element);
    }

    /**
     *  Clears the entire ChartDataSet.
     */
    public void clear () {
        dataSet.removeAllElements ();
    }

    /**
     *  Returns the element with the given index as a ChartItem
     *  @return ChartItem object representing the datapoint at index element.
     */
    public ChartItem getElementAt (int element) {
        return (ChartItem)dataSet.elementAt (element);
    }

    /**
     *  Returns the number of elements currently held in this ChartDataSet.
     *  @return int value representing the number of data points held in the set.
     */
    public int size () {
        return dataSet.size();
    }
}