package no.hig.okolloen.graphics.chart;

import java.awt.*;

/**
 * The BarChart class is used to draw (take a guess) line Charts.
 * Data is provided by an instance of the ScaledChartDataSet.
 * 
 * @author      Oivind Kolloen
 * @version     %I%, %G%
 * @since       rev 0.1
 */
public class LineChart extends Chart {
    int position;
    int increment;
    ScaledChartDataSet dataSet;
    boolean showTitles = false;
    boolean showMarkers = false;

    /**
     *	Constructor for the Chart class.
     *  @param dataSet the instance of the ScaledChartDataSet that acts as a data provider.
     */
    public LineChart (ScaledChartDataSet dataSet) {
        super ();
        this.dataSet = dataSet;
        labels = dataSet.getScaleLabels ();
    }

    /**
     *	Constructor for the Chart class.
     *  @param dataSet the instance of the ScaledChartDataSet that acts as a data provider.
     *  @param showMarkers boolean value that determines if a mark is to be shown for each data point.
     */
    public LineChart (ScaledChartDataSet dataSet, boolean showMarkers) {
        super ();
        this.dataSet = dataSet;
        labels = dataSet.getScaleLabels ();
        this.showTitles = showTitles;
    }

    /**
     *	Constructor for the Chart class.
     *  @param dataSet the instance of the ScaledChartDataSet that acts as a data provider.
     *  @param showMarkers boolean value that determines if a mark is to be shown for each data point.
     *  @param showTitles boolean value that determines if the titles given trough the dataset is to be shown for each data point.
     */
    public LineChart (ScaledChartDataSet dataSet, boolean showMarkers, boolean showTitles) {
        super ();
        this.dataSet = dataSet;
        labels = dataSet.getScaleLabels ();
        this.showTitles = showTitles;
        this.showMarkers = showMarkers;
    }

    /**
     *	Updates this component.
     *  @param g the Graphics context.
     *	@see java.awt.Component#update
     */
    public void update(Graphics g) {
        paint(g);
    }

    /**
     *	Paints this component.
     *	@param g the Graphics context.
     *	@see java.awt.Component#paint
     */	
    public void paint (Graphics g) {
        super.paint (g);
        int height = getSize().height;
        int width = getSize().width;
     
        increment = (right-left)/dataSet.size();
        position = left;
        Color temp = bg.getColor ();
        ChartItem thisItem = (ChartItem)dataSet.getElementAt(0);
        int thisAdjustedValue = (int)(bottom-(bottom-top)*dataSet.getScaledElementAt(0));
        g.setColor (thisItem.getColor());
        if (showTitles)
            if (thisItem.getTitle()!=null)
                bg.drawString (thisItem.getTitle(), position-fm.stringWidth(thisItem.getTitle()), thisAdjustedValue-2);
        if (showMarkers)
            bg.fillOval (position-2, thisAdjustedValue-2, 4, 4);
        ChartItem nextItem = null;
        int nextAdjustedValue = 0;
        for (int i=0; i<dataSet.size()-1; i++) {
            if (nextItem!=null) {
                thisItem = nextItem;
                thisAdjustedValue = nextAdjustedValue;
            } else {
                thisItem = (ChartItem)dataSet.getElementAt(i);
                thisAdjustedValue = (int)(bottom-(bottom-top)*dataSet.getScaledElementAt(i));
            }
            nextItem = (ChartItem)dataSet.getElementAt(i+1);
            bg.setColor (nextItem.getColor ());
            nextAdjustedValue = (int)(bottom-(bottom-top)*dataSet.getScaledElementAt(i+1));
         
            bg.drawLine (position, thisAdjustedValue, position+=increment, nextAdjustedValue);
            if (showTitles)
                if (nextItem.getTitle()!=null) {
                    if (nextAdjustedValue < thisAdjustedValue)
                        bg.drawString (nextItem.getTitle(), position-fm.stringWidth(nextItem.getTitle()), nextAdjustedValue+fontHeight+4);
                    else
                        bg.drawString (nextItem.getTitle(), position-fm.stringWidth(nextItem.getTitle()), nextAdjustedValue-4);
                }
            if (showMarkers)
                bg.fillOval (position-2, nextAdjustedValue-2, 4, 4);
        }
        bg.setColor (temp);
        g.drawImage(buffer, 0, 0, this);
        g.dispose ();
    }

    /**
     *	Returns the preferred size of this component.
     *	@return A Dimension object representing the preferred size of this component.
     *	@see java.awt.Component#getPreferredSize
     */
    public Dimension getPreferredSize() {
        return new Dimension(300, 200);
    }
}